==> haskell-openssl-streams-1.2.1.3-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-DvS6rysEgUJ4scNTDrVfzw
key: openssl-streams-1.2.1.3-DvS6rysEgUJ4scNTDrVfzw
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: 48eb9de11e658d107f70271059e5d528
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-DvS6rysEgUJ4scNTDrVfzw
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    HsOpenSSL-0.11.4.14-IPWvQrRLW0NCIn5oBY5ldK
    io-streams-1.5.0.1-IYeBBvuoDFjClIohawF1WY
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             HsOpenSSL-0.11.4.14-IPWvQrRLW0NCIn5oBY5ldK=d37d3f58c9f49e5b1d027e1ec6d33222
             io-streams-1.5.0.1-IYeBBvuoDFjClIohawF1WY=8b3312482f87aba091b27558a2717289
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.1.3-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-HSr8jIT9nBe8NiEy7qw38I
key: openssl-streams-1.2.1.3-HSr8jIT9nBe8NiEy7qw38I
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: b3e9361372cbd22badb0b2a1b2d09328
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-HSr8jIT9nBe8NiEy7qw38I
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    HsOpenSSL-0.11.4.15-6N0Ep8lT6xfEo3bwc607vY
    io-streams-1.5.0.1-2bVNxAA2r1O57zSFpx0loj
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             HsOpenSSL-0.11.4.15-6N0Ep8lT6xfEo3bwc607vY=7d0c8c985cef11cfd83a0fb4bcd1ee15
             io-streams-1.5.0.1-2bVNxAA2r1O57zSFpx0loj=c29d11fe530951aff4dc7b9acd92aa68
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
